@@ -3,7 +3,7 @@ package CGI::Wiki;
 use strict;
 
 use vars qw( $VERSION );
-$VERSION = '0.48';
+$VERSION = '0.49';
 
 use Carp qw(croak carp);
 use Digest::MD5 "md5_hex";
@@ -273,23 +273,33 @@ sub list_all_nodes {
 
 =item B<list_nodes_by_metadata>
 
-  # All nodes that Kake's watching.
+  # All documentation nodes.
   my @nodes = $wiki->list_nodes_by_metadata(
-      metadata_type  => "watched_by",
-      metadata_value => "Kake"              );
+      metadata_type  => "category",
+      metadata_value => "documentation",
+      ignore_case    => 1,   # optional but recommended (see below)
+  );
 
   # All pubs in Hammersmith.
   my @pubs = $wiki->list_nodes_by_metadata(
       metadata_type  => "category",
-      metadata_value => "Pub"              );
+      metadata_value => "Pub",
+  );
   my @hsm  = $wiki->list_nodes_by_metadata(
       metadata_type  => "category",
-      metadata_value  => "Hammersmith"     );
+      metadata_value  => "Hammersmith",
+  );
   my @results = my_l33t_method_for_ANDing_arrays( \@pubs, \@hsm );
 
 Returns a list containing the name of every node whose caller-supplied
 metadata matches the criteria given in the parameters.
 
+By default, the case-sensitivity of both C<metadata_type> and
+C<metadata_value> depends on your database - if it will return rows
+with an attribute value of "Pubs" when you asked for "pubs", or not.
+If you supply a true value to the C<ignore_case> parameter, then you
+can be sure of its being case-insensitive.  This is recommended.
+
 If you don't supply any criteria then you'll get an empty list.
 
 This is a really really really simple way of finding things; if you
